/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *                                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "UCQHelpBrowser.h"

/**
 * \brief Constructs the window and connects the signals and slots of the
 *        contained controls.
 *
 * \param parent Pointer to the parent QWidget.
 */
UCQHelpBrowser::UCQHelpBrowser ( QWidget* parent ) :
    QWidget ( parent )
{
    ui_.setupUi ( this );
    setWindowFlags ( Qt::Window );

    QIcon iconHome    ( ":icons/go-home.svg"        );
    QIcon iconForward ( ":icons/go-next.svg"        );
    QIcon iconBack    ( ":icons/go-previous.svg"    );
    QIcon iconClose   ( ":icons/system-log-out.svg" );

    ui_.buttonHome->setIcon    ( iconHome    );
    ui_.buttonBack->setIcon    ( iconBack    );
    ui_.buttonClose->setIcon   ( iconClose   );
    ui_.buttonForward->setIcon ( iconForward );

    connect ( ui_.buttonClose, SIGNAL ( clicked () ),
              this,            SLOT   ( close   () ));

    connect ( ui_.buttonHome,  SIGNAL ( clicked () ),
              ui_.mainBrowser, SLOT   ( home    () ));

    connect ( ui_.buttonBack,  SIGNAL ( clicked  () ),
              ui_.mainBrowser, SLOT   ( backward () ));

    connect ( ui_.buttonForward, SIGNAL ( clicked () ),
              ui_.mainBrowser,   SLOT   ( forward () ));

    connect ( ui_.mainBrowser, SIGNAL ( sourceChanged ( const QUrl & ) ),
              this,            SLOT   ( updateWindowTitle ()           ));

    connect ( ui_.mainBrowser, SIGNAL ( forwardAvailable ( bool ) ),
              this,            SLOT   ( updateForward ( bool )    ));

    connect ( ui_.mainBrowser, SIGNAL ( backwardAvailable ( bool ) ),
              this,            SLOT   ( updateBack        ( bool ) ));

    // Try to display the help in the local language.
    // The resourcepath depends on the system.
#if defined(LINUX)
    QDir dir(HELPPATH);
#else
    QDir dir ( QApplication::applicationDirPath () );
#if defined(Q_OS_WIN)
    if (dir.dirName().toLower() == "debug"
            || dir.dirName().toLower() == "release")
    dir.cdUp();

#elif defined(Q_OS_MAC)
    if (dir.dirName() == "MacOS")
    {
        dir.cdUp();
        dir.cd("Resources");
    }

#endif
    dir.cd ( "help" );
#endif

    QString locale = QDir::toNativeSeparators ( dir.absolutePath ()
                   + QDir::separator () + QLocale::system ().name () );
    if ( !QDir ( locale ).exists () )
    {
        locale = dir.absolutePath () + QDir::separator () + "en_EN";
    }

    // set directories that are searched for helpfiles
    ui_.mainBrowser->setSearchPaths
                        ( QStringList () << locale << ":help/images" );

    ui_.mainBrowser->setSource ( QUrl ( "index.html" ) );
    ui_.mainBrowser->setOpenExternalLinks ( true );
}

/**
 * \brief Hides the window instead of closing it.
 *
 * The window will keep its state and will be deleted by the parent.
 */
void UCQHelpBrowser::closeEvent ( QCloseEvent* /*event*/)
{
    this->hide ();
    // jump back to index if about was shown
    if(ui_.mainBrowser->source() == QUrl ("about.html") ){
        ui_.mainBrowser->setSource ( QUrl ("index.html"));
    }
}

/**
 * \brief Displays the given page in the browser.
 *
 * \param page Path to the HTML file, that will be displayed. If empty, nothing
 *             happens.
 */
void UCQHelpBrowser::jumpTo ( const QString& page )
{
    ui_.mainBrowser->setSource ( QUrl ( page ) );
}

/**
 * \brief Dis-/Enables the back button.
 *
 * \param avail True to enable, false to disable the back button.
 */
void UCQHelpBrowser::updateBack ( bool avail )
{
    ui_.buttonBack->setEnabled ( avail );
}

/**
 * \brief Dis-/Enables the forward button.
 *
 * \param avail True to enable, false to disable the forward button.
 */
void UCQHelpBrowser::updateForward ( bool avail )
{
    ui_.buttonForward->setEnabled ( avail );
}

/**
 * \brief Appends the title of the displayed html file to the window title.
 */
void UCQHelpBrowser::updateWindowTitle ()
{
    setWindowTitle ( tr ( "Help: %1" ).arg ( ui_.mainBrowser->documentTitle () ) );
}
